==> kubernetes-model-extensions-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressLoadBalancerIngressFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IngressLoadBalancerIngressFluent<A extends IngressLoadBalancerIngressFluent<A>> extends BaseFluent<A>{
  public IngressLoadBalancerIngressFluent() {
  }
  public IngressLoadBalancerIngressFluent(IngressLoadBalancerIngress instance) {
    instance = (instance != null ? instance : new IngressLoadBalancerIngress());

    if (instance != null) {
      this.withHostname(instance.getHostname());
      this.withIp(instance.getIp());
      this.withPorts(instance.getPorts());
      this.withHostname(instance.getHostname());
      this.withIp(instance.getIp());
      this.withPorts(instance.getPorts());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String hostname;
  private String ip;
  private ArrayList<IngressPortStatusBuilder> ports = new ArrayList<IngressPortStatusBuilder>();
  private Map<String,Object> additionalProperties;
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIp() {
    return this.ip;
  }
  public A withIp(String ip) {
    this.ip=ip; return (A) this;
  }
  public boolean hasIp() {
    return this.ip != null;
  }
  public A addToPorts(int index,IngressPortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);
    if (index < 0 || index >= ports.size()) { _visitables.get("ports").add(builder); ports.add(builder); } else { _visitables.get("ports").add(index, builder); ports.add(index, builder);}
    return (A)this;
  }
  public A setToPorts(int index,IngressPortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);
    if (index < 0 || index >= ports.size()) { _visitables.get("ports").add(builder); ports.add(builder); } else { _visitables.get("ports").set(index, builder); ports.set(index, builder);}
    return (A)this;
  }
  public A addToPorts(io.fabric8.kubernetes.api.model.extensions.IngressPortStatus... items) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  public A addAllToPorts(Collection<IngressPortStatus> items) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  public A removeFromPorts(io.fabric8.kubernetes.api.model.extensions.IngressPortStatus... items) {
    if (this.ports == null) return (A)this;
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").remove(builder); this.ports.remove(builder);} return (A)this;
  }
  public A removeAllFromPorts(Collection<IngressPortStatus> items) {
    if (this.ports == null) return (A)this;
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").remove(builder); this.ports.remove(builder);} return (A)this;
  }
  public A removeMatchingFromPorts(Predicate<IngressPortStatusBuilder> predicate) {
    if (ports == null) return (A) this;
    final Iterator<IngressPortStatusBuilder> each = ports.iterator();
    final List visitables = _visitables.get("ports");
    while (each.hasNext()) {
      IngressPortStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<IngressPortStatus> buildPorts() {
    return ports != null ? build(ports) : null;
  }
  public IngressPortStatus buildPort(int index) {
    return this.ports.get(index).build();
  }
  public IngressPortStatus buildFirstPort() {
    return this.ports.get(0).build();
  }
  public IngressPortStatus buildLastPort() {
    return this.ports.get(ports.size() - 1).build();
  }
  public IngressPortStatus buildMatchingPort(Predicate<IngressPortStatusBuilder> predicate) {
    for (IngressPortStatusBuilder item: ports) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingPort(Predicate<IngressPortStatusBuilder> predicate) {
    for (IngressPortStatusBuilder item: ports) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPorts(List<IngressPortStatus> ports) {
    if (this.ports != null) { _visitables.get("ports").clear();}
    if (ports != null) {this.ports = new ArrayList(); for (IngressPortStatus item : ports){this.addToPorts(item);}} else { this.ports = null;} return (A) this;
  }
  public A withPorts(io.fabric8.kubernetes.api.model.extensions.IngressPortStatus... ports) {
    if (this.ports != null) {this.ports.clear(); _visitables.remove("ports"); }
    if (ports != null) {for (IngressPortStatus item :ports){ this.addToPorts(item);}} return (A) this;
  }
  public boolean hasPorts() {
    return ports != null && !ports.isEmpty();
  }
  public A addNewPort(String error,Integer port,String protocol) {
    return (A)addToPorts(new IngressPortStatus(error, port, protocol));
  }
  public PortsNested<A> addNewPort() {
    return new PortsNested(-1, null);
  }
  public PortsNested<A> addNewPortLike(IngressPortStatus item) {
    return new PortsNested(-1, item);
  }
  public PortsNested<A> setNewPortLike(int index,IngressPortStatus item) {
    return new PortsNested(index, item);
  }
  public PortsNested<A> editPort(int index) {
    if (ports.size() <= index) throw new RuntimeException("Can't edit ports. Index exceeds size.");
    return setNewPortLike(index, buildPort(index));
  }
  public PortsNested<A> editFirstPort() {
    if (ports.size() == 0) throw new RuntimeException("Can't edit first ports. The list is empty.");
    return setNewPortLike(0, buildPort(0));
  }
  public PortsNested<A> editLastPort() {
    int index = ports.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last ports. The list is empty.");
    return setNewPortLike(index, buildPort(index));
  }
  public PortsNested<A> editMatchingPort(Predicate<IngressPortStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<ports.size();i++) { 
    if (predicate.test(ports.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching ports. No match found.");
    return setNewPortLike(index, buildPort(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressLoadBalancerIngressFluent that = (IngressLoadBalancerIngressFluent) o;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(ip, that.ip)) return false;

    if (!java.util.Objects.equals(ports, that.ports)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  ip,  ports,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ip != null) { sb.append("ip:"); sb.append(ip + ","); }
    if (ports != null && !ports.isEmpty()) { sb.append("ports:"); sb.append(ports + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class PortsNested<N> extends IngressPortStatusFluent<PortsNested<N>> implements Nested<N>{
    PortsNested(int index,IngressPortStatus item) {
      this.index = index;
      this.builder = new IngressPortStatusBuilder(this, item);
    }
    IngressPortStatusBuilder builder;
    int index;
    public N and() {
      return (N) IngressLoadBalancerIngressFluent.this.setToPorts(index,builder.build());
    }
    public N endPort() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-extensions-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressLoadBalancerIngressFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IngressLoadBalancerIngressFluent<A extends IngressLoadBalancerIngressFluent<A>> extends BaseFluent<A>{
  public IngressLoadBalancerIngressFluent() {
  }
  
  public IngressLoadBalancerIngressFluent(IngressLoadBalancerIngress instance) {
    this.copyInstance(instance);
  }
  private String hostname;
  private String ip;
  private ArrayList<IngressPortStatusBuilder> ports = new ArrayList<IngressPortStatusBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(IngressLoadBalancerIngress instance) {
    instance = (instance != null ? instance : new IngressLoadBalancerIngress());
  
    if (instance != null) {
        this.withHostname(instance.getHostname());
        this.withIp(instance.getIp());
        this.withPorts(instance.getPorts());
        this.withHostname(instance.getHostname());
        this.withIp(instance.getIp());
        this.withPorts(instance.getPorts());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getHostname() {
    return this.hostname;
  }
  
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  
  public boolean hasHostname() {
    return this.hostname != null;
  }
  
  public String getIp() {
    return this.ip;
  }
  
  public A withIp(String ip) {
    this.ip=ip; return (A) this;
  }
  
  public boolean hasIp() {
    return this.ip != null;
  }
  
  public A addToPorts(int index,IngressPortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);
    if (index < 0 || index >= ports.size()) { _visitables.get("ports").add(builder); ports.add(builder); } else { _visitables.get("ports").add(index, builder); ports.add(index, builder);}
    return (A)this;
  }
  
  public A setToPorts(int index,IngressPortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);
    if (index < 0 || index >= ports.size()) { _visitables.get("ports").add(builder); ports.add(builder); } else { _visitables.get("ports").set(index, builder); ports.set(index, builder);}
    return (A)this;
  }
  
  public A addToPorts(io.fabric8.kubernetes.api.model.extensions.IngressPortStatus... items) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  
  public A addAllToPorts(Collection<IngressPortStatus> items) {
    if (this.ports == null) {this.ports = new ArrayList<IngressPortStatusBuilder>();}
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  
  public A removeFromPorts(io.fabric8.kubernetes.api.model.extensions.IngressPortStatus... items) {
    if (this.ports == null) return (A)this;
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").remove(builder); this.ports.remove(builder);} return (A)this;
  }
  
  public A removeAllFromPorts(Collection<IngressPortStatus> items) {
    if (this.ports == null) return (A)this;
    for (IngressPortStatus item : items) {IngressPortStatusBuilder builder = new IngressPortStatusBuilder(item);_visitables.get("ports").remove(builder); this.ports.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromPorts(Predicate<IngressPortStatusBuilder> predicate) {
    if (ports == null) return (A) this;
    final Iterator<IngressPortStatusBuilder> each = ports.iterator();
    final List visitables = _visitables.get("ports");
    while (each.hasNext()) {
      IngressPortStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<IngressPortStatus> buildPorts() {
    return ports != null ? build(ports) : null;
  }
  
  public IngressPortStatus buildPort(int index) {
    return this.ports.get(index).build();
  }
  
  public IngressPortStatus buildFirstPort() {
    return this.ports.get(0).build();
  }
  
  public IngressPortStatus buildLastPort() {
    return this.ports.get(ports.size() - 1).build();
  }
  
  public IngressPortStatus buildMatchingPort(Predicate<IngressPortStatusBuilder> predicate) {
    for (IngressPortStatusBuilder item: ports) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingPort(Predicate<IngressPortStatusBuilder> predicate) {
    for (IngressPortStatusBuilder item: ports) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withPorts(List<IngressPortStatus> ports) {
    if (this.ports != null) { _visitables.get("ports").clear();}
    if (ports != null) {this.ports = new ArrayList(); for (IngressPortStatus item : ports){this.addToPorts(item);}} else { this.ports = null;} return (A) this;
  }
  
  public A withPorts(io.fabric8.kubernetes.api.model.extensions.IngressPortStatus... ports) {
    if (this.ports != null) {this.ports.clear(); _visitables.remove("ports"); }
    if (ports != null) {for (IngressPortStatus item :ports){ this.addToPorts(item);}} return (A) this;
  }
  
  public boolean hasPorts() {
    return ports != null && !ports.isEmpty();
  }
  
  public A addNewPort(String error,Integer port,String protocol) {
    return (A)addToPorts(new IngressPortStatus(error, port, protocol));
  }
  
  public PortsNested<A> addNewPort() {
    return new PortsNested(-1, null);
  }
  
  public PortsNested<A> addNewPortLike(IngressPortStatus item) {
    return new PortsNested(-1, item);
  }
  
  public PortsNested<A> setNewPortLike(int index,IngressPortStatus item) {
    return new PortsNested(index, item);
  }
  
  public PortsNested<A> editPort(int index) {
    if (ports.size() <= index) throw new RuntimeException("Can't edit ports. Index exceeds size.");
    return setNewPortLike(index, buildPort(index));
  }
  
  public PortsNested<A> editFirstPort() {
    if (ports.size() == 0) throw new RuntimeException("Can't edit first ports. The list is empty.");
    return setNewPortLike(0, buildPort(0));
  }
  
  public PortsNested<A> editLastPort() {
    int index = ports.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last ports. The list is empty.");
    return setNewPortLike(index, buildPort(index));
  }
  
  public PortsNested<A> editMatchingPort(Predicate<IngressPortStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<ports.size();i++) { 
    if (predicate.test(ports.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching ports. No match found.");
    return setNewPortLike(index, buildPort(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressLoadBalancerIngressFluent that = (IngressLoadBalancerIngressFluent) o;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;
  
    if (!java.util.Objects.equals(ip, that.ip)) return false;
  
    if (!java.util.Objects.equals(ports, that.ports)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(hostname,  ip,  ports,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ip != null) { sb.append("ip:"); sb.append(ip + ","); }
    if (ports != null && !ports.isEmpty()) { sb.append("ports:"); sb.append(ports + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class PortsNested<N> extends IngressPortStatusFluent<PortsNested<N>> implements Nested<N>{
    PortsNested(int index,IngressPortStatus item) {
      this.index = index;
      this.builder = new IngressPortStatusBuilder(this, item);
    }
    IngressPortStatusBuilder builder;
    int index;
    
    public N and() {
      return (N) IngressLoadBalancerIngressFluent.this.setToPorts(index,builder.build());
    }
    
    public N endPort() {
      return and();
    }
    
  
  }

}
